@@ -18,7 +18,7 @@ import os
 import getpass
 import random
 import errno
-import netifaces as ni
+# import netifaces as ni
 
 username = getpass.getuser()
 
@@ -41,8 +41,10 @@ random_num = random.randint(1000, 9999)
 name = f"copiedfile{random_num}"
 
 # ni.ifaddresses('eth0')
-
-SERVER = input('Server HOST: ')
+print("______________________________________________________")
+print("")
+print("You can find out the ip address by typing\n \n $ ifconfig en1 \n\n or \n\n $ ifconfig en0\n\n or you can search google for it.\n\n")
+SERVER = input('Server HOST on which you want to run: ')
 
 # SERVER = socket.gethostbyname(socket.getfqdn())
 
@@ -112,5 +114,5 @@ def startserver():
         f"[RUNNING] The files which will be sent to you will be saved on {SAVE_DIR} directory.")
     start()
 
-
+print("______________________________________________________")
 startserver()
